@@ -21,11 +21,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "../config.h"
 
-#include "xpad-pad-properties.h"
-
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
+#include "xpad-pad-properties.h"
 
 struct XpadPadPropertiesPrivate
 {
@@ -256,7 +255,7 @@ xpad_pad_properties_set_property (GObject *object, guint prop_id, const GValue *
 		break;
 
 	case PROP_FONTNAME:
-		gtk_font_button_set_font_name (GTK_FONT_BUTTON (prop->priv->fontbutton), g_value_get_string (value));
+		gtk_font_chooser_set_font (GTK_FONT_CHOOSER (prop->priv->fontbutton), g_value_get_string (value));
 		break;
 
 	default:
@@ -291,7 +290,7 @@ xpad_pad_properties_get_property (GObject *object, guint prop_id, GValue *value,
 		break;
 
 	case PROP_FONTNAME:
-		g_value_set_string (value, gtk_font_button_get_font_name (GTK_FONT_BUTTON (prop->priv->fontbutton)));
+		g_value_set_string (value, gtk_font_chooser_get_font (GTK_FONT_CHOOSER (prop->priv->fontbutton)));
 		break;
 
 	default:
