@@ -2,6 +2,7 @@
 
 Copyright (c) 2001-2007 Michael Terry
 Copyright (c) 2010 Sergei Riaguzov
+Copyright (c) 2013-2014 Arthur Borsboom
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,9 +23,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __XPAD_UNDO_H__
 #define __XPAD_UNDO_H__
 
-#include <gtk/gtk.h>
 #include "xpad-text-buffer.h"
-#include "xpad-pad.h"
 
 G_BEGIN_DECLS
 
@@ -42,8 +41,6 @@ typedef struct XpadUndo XpadUndo;
 struct XpadUndo
 {
 	GObject parent;
-
-	/* private */
 	XpadUndoPrivate *priv;
 };
 
